#[repr(C)]pub struct DisplayId {
pub value: u64,
}Expand description
Unique identifier for a display device attached to the system.
[fuchsia.hardware.display.types/INVALID_DISP_ID] represents an invalid
value.
Values are unique within a [fuchsia.hardware.display/Controller]
connection. An external display will be associated with different display ID
values if it is disconnected and reconnected.
A display device may be identified by different values across boot cycles or
across different Controller connections. Software that needs to identify
displays (for example, to honor display-specific preferences) should use
[fuchsia.hardware.display/Info] identifiers, not display IDs.
This type is not related to the VESA DisplayID standard.
Fields
value: u64Trait Implementations
Sourceimpl<'a, ___E> Encode<DisplayId, ___E> for &'a DisplayIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DisplayId, ___E> for &'a DisplayIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<DisplayId, ___E> for DisplayIdwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DisplayId, ___E> for DisplayIdwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DisplayId, DisplayId>
const COPY_OPTIMIZATION: CopyOptimization<DisplayId, DisplayId>
Sourceimpl FromWireRef<DisplayId> for DisplayId
impl FromWireRef<DisplayId> for DisplayId
Sourcefn from_wire_ref(wire: &DisplayId) -> DisplayId
fn from_wire_ref(wire: &DisplayId) -> DisplayId
Converts the given reference to this type.
Sourceimpl Ord for DisplayId
impl Ord for DisplayId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for DisplayId
impl PartialOrd for DisplayId
impl Copy for DisplayId
impl Eq for DisplayId
impl StructuralPartialEq for DisplayId