#[repr(C)]pub struct ImageMetadata {
pub dimensions: SizeU,
pub tiling_type: u32,
}Expand description
Describes how an image is stored in a buffer of a sysmem BufferCollection.
The buffer is dedicated to storing a single image. The properties below are needed for decoding the image from the buffer.
Fields
dimensions: SizeUtiling_type: u32Trait Implementations
Sourceimpl Clone for ImageMetadata
impl Clone for ImageMetadata
Sourcefn clone(&self) -> ImageMetadata
fn clone(&self) -> ImageMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImageMetadata
impl Debug for ImageMetadata
Sourceimpl<'a, ___E> Encode<ImageMetadata, ___E> for &'a ImageMetadatawhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ImageMetadata, ___E> for &'a ImageMetadatawhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ImageMetadata>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ImageMetadata>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ImageMetadata, ___E> for ImageMetadatawhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ImageMetadata, ___E> for ImageMetadatawhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ImageMetadata, ImageMetadata>
const COPY_OPTIMIZATION: CopyOptimization<ImageMetadata, ImageMetadata>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ImageMetadata>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ImageMetadata>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ImageMetadata>, ___E> for &'a ImageMetadata
impl<'a, ___E> EncodeOption<Box<'static, ImageMetadata>, ___E> for &'a ImageMetadata
Sourcefn encode_option(
this: Option<&'a ImageMetadata>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ImageMetadata>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ImageMetadata>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ImageMetadata>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ImageMetadata>, ___E> for ImageMetadata
impl<___E> EncodeOption<Box<'static, ImageMetadata>, ___E> for ImageMetadata
Sourcefn encode_option(
this: Option<ImageMetadata>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ImageMetadata>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ImageMetadata>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ImageMetadata>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ImageMetadata> for ImageMetadata
impl FromWire<ImageMetadata> for ImageMetadata
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ImageMetadata, ImageMetadata>
const COPY_OPTIMIZATION: CopyOptimization<ImageMetadata, ImageMetadata>
Sourcefn from_wire(wire: ImageMetadata) -> ImageMetadata
fn from_wire(wire: ImageMetadata) -> ImageMetadata
Converts the given owned value to this type.
Sourceimpl FromWireRef<ImageMetadata> for ImageMetadata
impl FromWireRef<ImageMetadata> for ImageMetadata
Sourcefn from_wire_ref(wire: &ImageMetadata) -> ImageMetadata
fn from_wire_ref(wire: &ImageMetadata) -> ImageMetadata
Converts the given reference to this type.
Sourceimpl PartialEq for ImageMetadata
impl PartialEq for ImageMetadata
Sourcefn eq(&self, other: &ImageMetadata) -> bool
fn eq(&self, other: &ImageMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ImageMetadata