#[repr(C)]pub struct Mode {
pub active_area: SizeU,
pub refresh_rate_millihertz: u32,
pub flags: ModeFlags,
}Expand description
Describes an operational mode for a display device attached to the system.
The operational parameters that make up a mode description must be updated atomically, using a resource-intensive “mode setting” operation. Parameters that can be changed quickly, such as brightness and contrast, do not belong in a mode description.
Fields
active_area: SizeUrefresh_rate_millihertz: u32flags: ModeFlagsTrait Implementations
Sourceimpl<'a, ___E> Encode<Mode, ___E> for &'a Modewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Mode, ___E> for &'a Modewhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Mode, ___E> for Modewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Mode, ___E> for Modewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Mode, Mode>
const COPY_OPTIMIZATION: CopyOptimization<Mode, Mode>
Sourceimpl FromWireRef<Mode> for Mode
impl FromWireRef<Mode> for Mode
Sourcefn from_wire_ref(wire: &Mode) -> Mode
fn from_wire_ref(wire: &Mode) -> Mode
Converts the given reference to this type.
impl StructuralPartialEq for Mode